pub struct MockOrganizationDomainApi {
OrganizationDomainApi_expectations: MockOrganizationDomainApi_OrganizationDomainApi,
}Fields
OrganizationDomainApi_expectations: MockOrganizationDomainApi_OrganizationDomainApiImplementations
Sourceimpl MockOrganizationDomainApi
impl MockOrganizationDomainApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockOrganizationDomainApi
impl MockOrganizationDomainApi
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_all(&mut self) -> &mut Expectation
pub fn expect_get_all(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_all method
Sourcepub fn expect_get_verified_org_domain_sso_details(&mut self) -> &mut Expectation
pub fn expect_get_verified_org_domain_sso_details(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_verified_org_domain_sso_details method
Sourcepub fn expect_post(&mut self) -> &mut Expectation
pub fn expect_post(&mut self) -> &mut Expectation
Create an Expectation for mocking the post method
Sourcepub fn expect_remove_domain(&mut self) -> &mut Expectation
pub fn expect_remove_domain(&mut self) -> &mut Expectation
Create an Expectation for mocking the remove_domain method
Sourcepub fn expect_verify(&mut self) -> &mut Expectation
pub fn expect_verify(&mut self) -> &mut Expectation
Create an Expectation for mocking the verify method